# This file is autogenerated using make-errorcodes.R
libcurl_error_codes <- 
c("curl_error_unsupported_protocol", "curl_error_failed_init", 
"curl_error_url_malformat", "curl_error_not_built_in", "curl_error_couldnt_resolve_proxy", 
"curl_error_couldnt_resolve_host", "curl_error_couldnt_connect", 
"curl_error_weird_server_reply", "curl_error_remote_access_denied", 
"curl_error_ftp_accept_failed", "curl_error_ftp_weird_pass_reply", 
"curl_error_ftp_accept_timeout", "curl_error_ftp_weird_pasv_reply", 
"curl_error_ftp_weird_227_format", "curl_error_ftp_cant_get_host", 
"curl_error_http2", "curl_error_ftp_couldnt_set_type", "curl_error_partial_file", 
"curl_error_ftp_couldnt_retr_file", "curl_error_obsolete20", 
"curl_error_quote_error", "curl_error_http_returned_error", "curl_error_write_error", 
"curl_error_obsolete24", "curl_error_upload_failed", "curl_error_read_error", 
"curl_error_out_of_memory", "curl_error_operation_timedout", 
"curl_error_obsolete29", "curl_error_ftp_port_failed", "curl_error_ftp_couldnt_use_rest", 
"curl_error_obsolete32", "curl_error_range_error", "curl_error_http_post_error", 
"curl_error_ssl_connect_error", "curl_error_bad_download_resume", 
"curl_error_file_couldnt_read_file", "curl_error_ldap_cannot_bind", 
"curl_error_ldap_search_failed", "curl_error_obsolete40", "curl_error_function_not_found", 
"curl_error_aborted_by_callback", "curl_error_bad_function_argument", 
"curl_error_obsolete44", "curl_error_interface_failed", "curl_error_obsolete46", 
"curl_error_too_many_redirects", "curl_error_unknown_option", 
"curl_error_setopt_option_syntax", "curl_error_obsolete50", "curl_error_peer_failed_verification", 
"curl_error_got_nothing", "curl_error_ssl_engine_notfound", "curl_error_ssl_engine_setfailed", 
"curl_error_send_error", "curl_error_recv_error", "curl_error_obsolete57", 
"curl_error_ssl_certproblem", "curl_error_ssl_cipher", "curl_error_peer_failed_verification", 
"curl_error_bad_content_encoding", "curl_error_ldap_invalid_url", 
"curl_error_filesize_exceeded", "curl_error_use_ssl_failed", 
"curl_error_send_fail_rewind", "curl_error_ssl_engine_initfailed", 
"curl_error_login_denied", "curl_error_tftp_notfound", "curl_error_tftp_perm", 
"curl_error_remote_disk_full", "curl_error_tftp_illegal", "curl_error_tftp_unknownid", 
"curl_error_remote_file_exists", "curl_error_tftp_nosuchuser", 
"curl_error_conv_failed", "curl_error_conv_reqd", "curl_error_ssl_cacert_badfile", 
"curl_error_remote_file_not_found", "curl_error_ssh", "curl_error_ssl_shutdown_failed", 
"curl_error_again", "curl_error_ssl_crl_badfile", "curl_error_ssl_issuer_error", 
"curl_error_ftp_pret_failed", "curl_error_rtsp_cseq_error", "curl_error_rtsp_session_error", 
"curl_error_ftp_bad_file_list", "curl_error_chunk_failed", "curl_error_no_connection_available", 
"curl_error_ssl_pinnedpubkeynotmatch", "curl_error_ssl_invalidcertstatus", 
"curl_error_http2_stream", "curl_error_recursive_api_call", "curl_error_auth_error", 
"curl_error_http3", "curl_error_quic_connect_error", "curl_error_proxy", 
"curl_error_ssl_clientcert", "curl_error_unrecoverable_poll", 
"curl_error_too_large", "curl_error_ech_required")
