#include <curl/curl.h>

#define LIBCURL_HAS(x) \
  (defined(x ## _FIRST) && (x ## _FIRST <= LIBCURL_VERSION_NUM) && \
   (!defined(x ## _LAST) || ( x ## _LAST >= LIBCURL_VERSION_NUM)))

#define CURLAUTH_ANY_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLAUTH_ANYSAFE_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLAUTH_BASIC_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLAUTH_DIGEST_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLAUTH_DIGEST_IE_FIRST 0x071303 /* Added in 7.19.3 */
#define CURLAUTH_GSSNEGOTIATE_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLAUTH_NEGOTIATE_FIRST 0x072600 /* Added in 7.38.0 */
#define CURLAUTH_NONE_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLAUTH_NTLM_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLAUTH_NTLM_WB_FIRST 0x071600 /* Added in 7.22.0 */
#define CURLAUTH_ONLY_FIRST 0x071503 /* Added in 7.21.3 */
#define CURLCLOSEPOLICY_CALLBACK_FIRST 0x070700 /* Added in 7.7 */
#define CURLCLOSEPOLICY_LEAST_RECENTLY_USED_FIRST 0x070700 /* Added in 7.7 */
#define CURLCLOSEPOLICY_LEAST_TRAFFIC_FIRST 0x070700 /* Added in 7.7 */
#define CURLCLOSEPOLICY_NONE_FIRST 0x070700 /* Added in 7.7 */
#define CURLCLOSEPOLICY_OLDEST_FIRST 0x070700 /* Added in 7.7 */
#define CURLCLOSEPOLICY_SLOWEST_FIRST 0x070700 /* Added in 7.7 */
#define CURLE_ABORTED_BY_CALLBACK_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_AGAIN_FIRST 0x071202 /* Added in 7.18.2 */
#define CURLE_ALREADY_COMPLETE_FIRST 0x070702 /* Added in 7.7.2 */
#define CURLE_BAD_CALLING_ORDER_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_BAD_CONTENT_ENCODING_FIRST 0x070a00 /* Added in 7.10 */
#define CURLE_BAD_DOWNLOAD_RESUME_FIRST 0x070a00 /* Added in 7.10 */
#define CURLE_BAD_FUNCTION_ARGUMENT_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_BAD_PASSWORD_ENTERED_FIRST 0x070402 /* Added in 7.4.2 */
#define CURLE_CHUNK_FAILED_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLE_CONV_FAILED_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLE_CONV_REQD_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLE_COULDNT_CONNECT_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_COULDNT_RESOLVE_HOST_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_COULDNT_RESOLVE_PROXY_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FAILED_INIT_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FILESIZE_EXCEEDED_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLE_FILE_COULDNT_READ_FILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_ACCEPT_FAILED_FIRST 0x071800 /* Added in 7.24.0 */
#define CURLE_FTP_ACCEPT_TIMEOUT_FIRST 0x071800 /* Added in 7.24.0 */
#define CURLE_FTP_ACCESS_DENIED_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_BAD_DOWNLOAD_RESUME_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_BAD_FILE_LIST_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLE_FTP_CANT_GET_HOST_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_CANT_RECONNECT_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_COULDNT_GET_SIZE_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_COULDNT_RETR_FILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_COULDNT_SET_ASCII_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_COULDNT_SET_BINARY_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_COULDNT_SET_TYPE_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLE_FTP_COULDNT_STOR_FILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_COULDNT_USE_REST_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_PARTIAL_FILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_PORT_FAILED_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_PRET_FAILED_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLE_FTP_QUOTE_ERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_SSL_FAILED_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLE_FTP_USER_PASSWORD_INCORRECT_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_WEIRD_227_FORMAT_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_WEIRD_PASS_REPLY_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_WEIRD_PASV_REPLY_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_WEIRD_SERVER_REPLY_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_WEIRD_USER_REPLY_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FTP_WRITE_ERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_FUNCTION_NOT_FOUND_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_GOT_NOTHING_FIRST 0x070901 /* Added in 7.9.1 */
#define CURLE_HTTP2_FIRST 0x072600 /* Added in 7.38.0 */
#define CURLE_HTTP_NOT_FOUND_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_HTTP_PORT_FAILED_FIRST 0x070300 /* Added in 7.3 */
#define CURLE_HTTP_POST_ERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_HTTP_RANGE_ERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_HTTP_RETURNED_ERROR_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLE_INTERFACE_FAILED_FIRST 0x070c00 /* Added in 7.12.0 */
#define CURLE_LDAP_CANNOT_BIND_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_LDAP_INVALID_URL_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLE_LDAP_SEARCH_FAILED_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_LIBRARY_NOT_FOUND_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_LOGIN_DENIED_FIRST 0x070d01 /* Added in 7.13.1 */
#define CURLE_MALFORMAT_USER_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_NOT_BUILT_IN_FIRST 0x071505 /* Added in 7.21.5 */
#define CURLE_NO_CONNECTION_AVAILABLE_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLE_OK_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_OPERATION_TIMEDOUT_FIRST 0x070a02 /* Added in 7.10.2 */
#define CURLE_OPERATION_TIMEOUTED_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_OUT_OF_MEMORY_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_PARTIAL_FILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_PEER_FAILED_VERIFICATION_FIRST 0x071101 /* Added in 7.17.1 */
#define CURLE_QUOTE_ERROR_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLE_RANGE_ERROR_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLE_READ_ERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_RECV_ERROR_FIRST 0x070a00 /* Added in 7.10 */
#define CURLE_REMOTE_ACCESS_DENIED_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLE_REMOTE_DISK_FULL_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLE_REMOTE_FILE_EXISTS_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLE_REMOTE_FILE_NOT_FOUND_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLE_RTSP_CSEQ_ERROR_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLE_RTSP_SESSION_ERROR_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLE_SEND_ERROR_FIRST 0x070a00 /* Added in 7.10 */
#define CURLE_SEND_FAIL_REWIND_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLE_SHARE_IN_USE_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLE_SSH_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLE_SSL_CACERT_FIRST 0x070a00 /* Added in 7.10 */
#define CURLE_SSL_CACERT_BADFILE_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLE_SSL_CERTPROBLEM_FIRST 0x070a00 /* Added in 7.10 */
#define CURLE_SSL_CIPHER_FIRST 0x070a00 /* Added in 7.10 */
#define CURLE_SSL_CONNECT_ERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_SSL_CRL_BADFILE_FIRST 0x071300 /* Added in 7.19.0 */
#define CURLE_SSL_ENGINE_INITFAILED_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLE_SSL_ENGINE_NOTFOUND_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLE_SSL_ENGINE_SETFAILED_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLE_SSL_INVALIDCERTSTATUS_FIRST 0x072900 /* Added in 7.41.0 */
#define CURLE_SSL_ISSUER_ERROR_FIRST 0x071300 /* Added in 7.19.0 */
#define CURLE_SSL_PEER_CERTIFICATE_FIRST 0x070800 /* Added in 7.8 */
#define CURLE_SSL_PINNEDPUBKEYNOTMATCH_FIRST 0x072700 /* Added in 7.39.0 */
#define CURLE_SSL_SHUTDOWN_FAILED_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLE_TELNET_OPTION_SYNTAX_FIRST 0x070700 /* Added in 7.7 */
#define CURLE_TFTP_DISKFULL_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLE_TFTP_EXISTS_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLE_TFTP_ILLEGAL_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLE_TFTP_NOSUCHUSER_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLE_TFTP_NOTFOUND_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLE_TFTP_PERM_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLE_TFTP_UNKNOWNID_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLE_TOO_MANY_REDIRECTS_FIRST 0x070500 /* Added in 7.5 */
#define CURLE_UNKNOWN_OPTION_FIRST 0x071505 /* Added in 7.21.5 */
#define CURLE_UNKNOWN_TELNET_OPTION_FIRST 0x070700 /* Added in 7.7 */
#define CURLE_UNSUPPORTED_PROTOCOL_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_UPLOAD_FAILED_FIRST 0x071003 /* Added in 7.16.3 */
#define CURLE_URL_MALFORMAT_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_URL_MALFORMAT_USER_FIRST 0x070100 /* Added in 7.1 */
#define CURLE_USE_SSL_FAILED_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLE_WRITE_ERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLFILETYPE_DEVICE_BLOCK_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_DEVICE_CHAR_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_DIRECTORY_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_DOOR_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_FILE_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_NAMEDPIPE_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_SOCKET_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_SYMLINK_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFILETYPE_UNKNOWN_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_FILENAME_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_FILETYPE_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_GID_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_HLINKCOUNT_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_PERM_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_SIZE_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_TIME_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFINFOFLAG_KNOWN_UID_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLFORM_ARRAY_FIRST 0x070901 /* Added in 7.9.1 */
#define CURLFORM_ARRAY_END_FIRST 0x070901 /* Added in 7.9.1 */
#define CURLFORM_ARRAY_END_LAST 0x070906 /* Last featured in 7.9.6 */
#define CURLFORM_ARRAY_START_FIRST 0x070901 /* Added in 7.9.1 */
#define CURLFORM_ARRAY_START_LAST 0x070906 /* Last featured in 7.9.6 */
#define CURLFORM_BUFFER_FIRST 0x070908 /* Added in 7.9.8 */
#define CURLFORM_BUFFERLENGTH_FIRST 0x070908 /* Added in 7.9.8 */
#define CURLFORM_BUFFERPTR_FIRST 0x070908 /* Added in 7.9.8 */
#define CURLFORM_CONTENTHEADER_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLFORM_CONTENTSLENGTH_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_CONTENTTYPE_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_COPYCONTENTS_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_COPYNAME_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_END_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_FILE_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_FILECONTENT_FIRST 0x070901 /* Added in 7.9.1 */
#define CURLFORM_FILENAME_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLFORM_NAMELENGTH_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_NOTHING_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_PTRCONTENTS_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_PTRNAME_FIRST 0x070900 /* Added in 7.9 */
#define CURLFORM_STREAM_FIRST 0x071202 /* Added in 7.18.2 */
#define CURLFTPAUTH_DEFAULT_FIRST 0x070c02 /* Added in 7.12.2 */
#define CURLFTPAUTH_SSL_FIRST 0x070c02 /* Added in 7.12.2 */
#define CURLFTPAUTH_TLS_FIRST 0x070c02 /* Added in 7.12.2 */
#define CURLFTPMETHOD_DEFAULT_FIRST 0x070f03 /* Added in 7.15.3 */
#define CURLFTPMETHOD_MULTICWD_FIRST 0x070f03 /* Added in 7.15.3 */
#define CURLFTPMETHOD_NOCWD_FIRST 0x070f03 /* Added in 7.15.3 */
#define CURLFTPMETHOD_SINGLECWD_FIRST 0x070f03 /* Added in 7.15.3 */
#define CURLFTPSSL_ALL_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLFTPSSL_CCC_ACTIVE_FIRST 0x071002 /* Added in 7.16.2 */
#define CURLFTPSSL_CCC_NONE_FIRST 0x071002 /* Added in 7.16.2 */
#define CURLFTPSSL_CCC_PASSIVE_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLFTPSSL_CONTROL_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLFTPSSL_NONE_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLFTPSSL_TRY_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLFTP_CREATE_DIR_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLFTP_CREATE_DIR_NONE_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLFTP_CREATE_DIR_RETRY_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLGSSAPI_DELEGATION_FLAG_FIRST 0x071600 /* Added in 7.22.0 */
#define CURLGSSAPI_DELEGATION_NONE_FIRST 0x071600 /* Added in 7.22.0 */
#define CURLGSSAPI_DELEGATION_POLICY_FLAG_FIRST 0x071600 /* Added in 7.22.0 */
#define CURLHEADER_SEPARATE_FIRST 0x072500 /* Added in 7.37.0 */
#define CURLHEADER_UNIFIED_FIRST 0x072500 /* Added in 7.37.0 */
#define CURLINFO_APPCONNECT_TIME_FIRST 0x071300 /* Added in 7.19.0 */
#define CURLINFO_CERTINFO_FIRST 0x071301 /* Added in 7.19.1 */
#define CURLINFO_CONDITION_UNMET_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLINFO_CONNECT_TIME_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_CONTENT_LENGTH_DOWNLOAD_FIRST 0x070601 /* Added in 7.6.1 */
#define CURLINFO_CONTENT_LENGTH_UPLOAD_FIRST 0x070601 /* Added in 7.6.1 */
#define CURLINFO_CONTENT_TYPE_FIRST 0x070904 /* Added in 7.9.4 */
#define CURLINFO_COOKIELIST_FIRST 0x070e01 /* Added in 7.14.1 */
#define CURLINFO_DATA_IN_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLINFO_DATA_OUT_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLINFO_DOUBLE_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_EFFECTIVE_URL_FIRST 0x070400 /* Added in 7.4 */
#define CURLINFO_END_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLINFO_FILETIME_FIRST 0x070500 /* Added in 7.5 */
#define CURLINFO_FTP_ENTRY_PATH_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLINFO_HEADER_IN_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLINFO_HEADER_OUT_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLINFO_HEADER_SIZE_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_HTTPAUTH_AVAIL_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLINFO_HTTP_CODE_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_HTTP_CONNECTCODE_FIRST 0x070a07 /* Added in 7.10.7 */
#define CURLINFO_LASTONE_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_LASTSOCKET_FIRST 0x070f02 /* Added in 7.15.2 */
#define CURLINFO_LOCAL_IP_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLINFO_LOCAL_PORT_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLINFO_LONG_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_MASK_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_NAMELOOKUP_TIME_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_NONE_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_NUM_CONNECTS_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLINFO_OS_ERRNO_FIRST 0x070c02 /* Added in 7.12.2 */
#define CURLINFO_PRETRANSFER_TIME_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_PRIMARY_IP_FIRST 0x071300 /* Added in 7.19.0 */
#define CURLINFO_PRIMARY_PORT_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLINFO_PRIVATE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLINFO_PROXYAUTH_AVAIL_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLINFO_REDIRECT_COUNT_FIRST 0x070907 /* Added in 7.9.7 */
#define CURLINFO_REDIRECT_TIME_FIRST 0x070907 /* Added in 7.9.7 */
#define CURLINFO_REDIRECT_URL_FIRST 0x071202 /* Added in 7.18.2 */
#define CURLINFO_REQUEST_SIZE_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_RESPONSE_CODE_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLINFO_RTSP_CLIENT_CSEQ_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLINFO_RTSP_CSEQ_RECV_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLINFO_RTSP_SERVER_CSEQ_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLINFO_RTSP_SESSION_ID_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLINFO_SIZE_DOWNLOAD_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_SIZE_UPLOAD_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_SLIST_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLINFO_SPEED_DOWNLOAD_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_SPEED_UPLOAD_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_SSL_DATA_IN_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLINFO_SSL_DATA_OUT_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLINFO_SSL_ENGINES_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLINFO_SSL_VERIFYRESULT_FIRST 0x070500 /* Added in 7.5 */
#define CURLINFO_STARTTRANSFER_TIME_FIRST 0x070902 /* Added in 7.9.2 */
#define CURLINFO_STRING_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_TEXT_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLINFO_TLS_SESSION_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLINFO_TOTAL_TIME_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLINFO_TYPEMASK_FIRST 0x070401 /* Added in 7.4.1 */
#define CURLIOCMD_NOP_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLIOCMD_RESTARTREAD_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLIOE_FAILRESTART_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLIOE_OK_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLIOE_UNKNOWNCMD_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLKHMATCH_MISMATCH_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHMATCH_MISSING_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHMATCH_OK_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHSTAT_DEFER_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHSTAT_FINE_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHSTAT_FINE_ADD_TO_FILE_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHSTAT_REJECT_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHTYPE_DSS_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHTYPE_RSA_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHTYPE_RSA1_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLKHTYPE_UNKNOWN_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLMOPT_CHUNK_LENGTH_PENALTY_SIZE_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLMOPT_CONTENT_LENGTH_PENALTY_SIZE_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLMOPT_MAXCONNECTS_FIRST 0x071003 /* Added in 7.16.3 */
#define CURLMOPT_MAX_HOST_CONNECTIONS_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLMOPT_MAX_PIPELINE_LENGTH_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLMOPT_MAX_TOTAL_CONNECTIONS_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLMOPT_PIPELINING_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLMOPT_PIPELINING_SERVER_BL_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLMOPT_PIPELINING_SITE_BL_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURLMOPT_SOCKETDATA_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLMOPT_SOCKETFUNCTION_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLMOPT_TIMERDATA_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLMOPT_TIMERFUNCTION_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLMSG_DONE_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLMSG_NONE_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLM_ADDED_ALREADY_FIRST 0x072001 /* Added in 7.32.1 */
#define CURLM_BAD_EASY_HANDLE_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLM_BAD_HANDLE_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLM_BAD_SOCKET_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLM_CALL_MULTI_PERFORM_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLM_CALL_MULTI_SOCKET_FIRST 0x070f05 /* Added in 7.15.5 */
#define CURLM_INTERNAL_ERROR_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLM_OK_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLM_OUT_OF_MEMORY_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLM_UNKNOWN_OPTION_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLOPTTYPE_FUNCTIONPOINT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPTTYPE_LONG_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPTTYPE_OBJECTPOINT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPTTYPE_OFF_T_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLOPT_ACCEPTTIMEOUT_MS_FIRST 0x071800 /* Added in 7.24.0 */
#define CURLOPT_ACCEPT_ENCODING_FIRST 0x071506 /* Added in 7.21.6 */
#define CURLOPT_ADDRESS_SCOPE_FIRST 0x071300 /* Added in 7.19.0 */
#define CURLOPT_APPEND_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLOPT_AUTOREFERER_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_BUFFERSIZE_FIRST 0x070a00 /* Added in 7.10 */
#define CURLOPT_CAINFO_FIRST 0x070402 /* Added in 7.4.2 */
#define CURLOPT_CAPATH_FIRST 0x070908 /* Added in 7.9.8 */
#define CURLOPT_CERTINFO_FIRST 0x071301 /* Added in 7.19.1 */
#define CURLOPT_CHUNK_BGN_FUNCTION_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLOPT_CHUNK_DATA_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLOPT_CHUNK_END_FUNCTION_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLOPT_CLOSEFUNCTION_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_CLOSEFUNCTION_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_CLOSEPOLICY_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_CLOSESOCKETDATA_FIRST 0x071507 /* Added in 7.21.7 */
#define CURLOPT_CLOSESOCKETFUNCTION_FIRST 0x071507 /* Added in 7.21.7 */
#define CURLOPT_CONNECTTIMEOUT_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_CONNECTTIMEOUT_MS_FIRST 0x071002 /* Added in 7.16.2 */
#define CURLOPT_CONNECT_ONLY_FIRST 0x070f02 /* Added in 7.15.2 */
#define CURLOPT_CONV_FROM_NETWORK_FUNCTION_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLOPT_CONV_FROM_UTF8_FUNCTION_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLOPT_CONV_TO_NETWORK_FUNCTION_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURLOPT_COOKIE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_COOKIEFILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_COOKIEJAR_FIRST 0x070900 /* Added in 7.9 */
#define CURLOPT_COOKIELIST_FIRST 0x070e01 /* Added in 7.14.1 */
#define CURLOPT_COOKIESESSION_FIRST 0x070907 /* Added in 7.9.7 */
#define CURLOPT_COPYPOSTFIELDS_FIRST 0x071101 /* Added in 7.17.1 */
#define CURLOPT_CRLF_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_CRLFILE_FIRST 0x071300 /* Added in 7.19.0 */
#define CURLOPT_CUSTOMREQUEST_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_DEBUGDATA_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLOPT_DEBUGFUNCTION_FIRST 0x070906 /* Added in 7.9.6 */
#define CURLOPT_DIRLISTONLY_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLOPT_DNS_CACHE_TIMEOUT_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_DNS_INTERFACE_FIRST 0x072100 /* Added in 7.33.0 */
#define CURLOPT_DNS_LOCAL_IP4_FIRST 0x072100 /* Added in 7.33.0 */
#define CURLOPT_DNS_LOCAL_IP6_FIRST 0x072100 /* Added in 7.33.0 */
#define CURLOPT_DNS_SERVERS_FIRST 0x071800 /* Added in 7.24.0 */
#define CURLOPT_DNS_USE_GLOBAL_CACHE_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_EGDSOCKET_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_ENCODING_FIRST 0x070a00 /* Added in 7.10 */
#define CURLOPT_ERRORBUFFER_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_EXPECT_100_TIMEOUT_MS_FIRST 0x072400 /* Added in 7.36.0 */
#define CURLOPT_FAILONERROR_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_FILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_FILETIME_FIRST 0x070500 /* Added in 7.5 */
#define CURLOPT_FNMATCH_DATA_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLOPT_FNMATCH_FUNCTION_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLOPT_FOLLOWLOCATION_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_FORBID_REUSE_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_FRESH_CONNECT_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_FTPAPPEND_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_FTPASCII_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_FTPASCII_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_FTPLISTONLY_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_FTPPORT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_FTPSSLAUTH_FIRST 0x070c02 /* Added in 7.12.2 */
#define CURLOPT_FTP_ACCOUNT_FIRST 0x070d00 /* Added in 7.13.0 */
#define CURLOPT_FTP_ALTERNATIVE_TO_USER_FIRST 0x070f05 /* Added in 7.15.5 */
#define CURLOPT_FTP_CREATE_MISSING_DIRS_FIRST 0x070a07 /* Added in 7.10.7 */
#define CURLOPT_FTP_FILEMETHOD_FIRST 0x070f01 /* Added in 7.15.1 */
#define CURLOPT_FTP_RESPONSE_TIMEOUT_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLOPT_FTP_SKIP_PASV_IP_FIRST 0x070f00 /* Added in 7.15.0 */
#define CURLOPT_FTP_SSL_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLOPT_FTP_SSL_CCC_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLOPT_FTP_USE_EPRT_FIRST 0x070a05 /* Added in 7.10.5 */
#define CURLOPT_FTP_USE_EPSV_FIRST 0x070902 /* Added in 7.9.2 */
#define CURLOPT_FTP_USE_PRET_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_GSSAPI_DELEGATION_FIRST 0x071600 /* Added in 7.22.0 */
#define CURLOPT_HEADER_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_HEADERDATA_FIRST 0x070a00 /* Added in 7.10 */
#define CURLOPT_HEADERFUNCTION_FIRST 0x070702 /* Added in 7.7.2 */
#define CURLOPT_HEADEROPT_FIRST 0x072500 /* Added in 7.37.0 */
#define CURLOPT_HTTP200ALIASES_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLOPT_HTTPAUTH_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLOPT_HTTPGET_FIRST 0x070801 /* Added in 7.8.1 */
#define CURLOPT_HTTPHEADER_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_HTTPPOST_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_HTTPPROXYTUNNEL_FIRST 0x070300 /* Added in 7.3 */
#define CURLOPT_HTTPREQUEST_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_HTTPREQUEST_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_HTTP_CONTENT_DECODING_FIRST 0x071002 /* Added in 7.16.2 */
#define CURLOPT_HTTP_TRANSFER_DECODING_FIRST 0x071002 /* Added in 7.16.2 */
#define CURLOPT_HTTP_VERSION_FIRST 0x070901 /* Added in 7.9.1 */
#define CURLOPT_IGNORE_CONTENT_LENGTH_FIRST 0x070e01 /* Added in 7.14.1 */
#define CURLOPT_INFILE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_INFILESIZE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_INFILESIZE_LARGE_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLOPT_INTERFACE_FIRST 0x070300 /* Added in 7.3 */
#define CURLOPT_INTERLEAVEDATA_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_INTERLEAVEFUNCTION_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_IOCTLDATA_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLOPT_IOCTLFUNCTION_FIRST 0x070c03 /* Added in 7.12.3 */
#define CURLOPT_IPRESOLVE_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLOPT_ISSUERCERT_FIRST 0x071300 /* Added in 7.19.0 */
#define CURLOPT_KEYPASSWD_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLOPT_KRB4LEVEL_FIRST 0x070300 /* Added in 7.3 */
#define CURLOPT_KRBLEVEL_FIRST 0x071004 /* Added in 7.16.4 */
#define CURLOPT_LOCALPORT_FIRST 0x070f02 /* Added in 7.15.2 */
#define CURLOPT_LOCALPORTRANGE_FIRST 0x070f02 /* Added in 7.15.2 */
#define CURLOPT_LOGIN_OPTIONS_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLOPT_LOW_SPEED_LIMIT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_LOW_SPEED_TIME_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_MAIL_AUTH_FIRST 0x071900 /* Added in 7.25.0 */
#define CURLOPT_MAIL_FROM_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_MAIL_RCPT_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_MAXCONNECTS_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_MAXFILESIZE_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURLOPT_MAXFILESIZE_LARGE_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLOPT_MAXREDIRS_FIRST 0x070500 /* Added in 7.5 */
#define CURLOPT_MAX_RECV_SPEED_LARGE_FIRST 0x070f05 /* Added in 7.15.5 */
#define CURLOPT_MAX_SEND_SPEED_LARGE_FIRST 0x070f05 /* Added in 7.15.5 */
#define CURLOPT_MUTE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_MUTE_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_NETRC_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_NETRC_FILE_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLOPT_NEW_DIRECTORY_PERMS_FIRST 0x071004 /* Added in 7.16.4 */
#define CURLOPT_NEW_FILE_PERMS_FIRST 0x071004 /* Added in 7.16.4 */
#define CURLOPT_NOBODY_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_NOPROGRESS_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_NOPROXY_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLOPT_NOSIGNAL_FIRST 0x070a00 /* Added in 7.10 */
#define CURLOPT_NOTHING_FIRST 0x070101 /* Added in 7.1.1 */
#define CURLOPT_NOTHING_LAST 0x070b00 /* Last featured in 7.11.0 */
#define CURLOPT_OPENSOCKETDATA_FIRST 0x071101 /* Added in 7.17.1 */
#define CURLOPT_OPENSOCKETFUNCTION_FIRST 0x071101 /* Added in 7.17.1 */
#define CURLOPT_PASSWDDATA_FIRST 0x070402 /* Added in 7.4.2 */
#define CURLOPT_PASSWDDATA_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_PASSWDFUNCTION_FIRST 0x070402 /* Added in 7.4.2 */
#define CURLOPT_PASSWDFUNCTION_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_PASSWORD_FIRST 0x071301 /* Added in 7.19.1 */
#define CURLOPT_PASV_HOST_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLOPT_PASV_HOST_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_PINNEDPUBLICKEY_FIRST 0x072700 /* Added in 7.39.0 */
#define CURLOPT_PORT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_POST_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_POST301_FIRST 0x071101 /* Added in 7.17.1 */
#define CURLOPT_POSTFIELDS_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_POSTFIELDSIZE_FIRST 0x070200 /* Added in 7.2 */
#define CURLOPT_POSTFIELDSIZE_LARGE_FIRST 0x070b01 /* Added in 7.11.1 */
#define CURLOPT_POSTQUOTE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_POSTREDIR_FIRST 0x071301 /* Added in 7.19.1 */
#define CURLOPT_PREQUOTE_FIRST 0x070905 /* Added in 7.9.5 */
#define CURLOPT_PRIVATE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLOPT_PROGRESSDATA_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_PROGRESSFUNCTION_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_PROTOCOLS_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLOPT_PROXY_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_PROXYAUTH_FIRST 0x070a07 /* Added in 7.10.7 */
#define CURLOPT_PROXYHEADER_FIRST 0x072500 /* Added in 7.37.0 */
#define CURLOPT_PROXYPASSWORD_FIRST 0x071301 /* Added in 7.19.1 */
#define CURLOPT_PROXYPORT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_PROXYTYPE_FIRST 0x070a00 /* Added in 7.10 */
#define CURLOPT_PROXYUSERNAME_FIRST 0x071301 /* Added in 7.19.1 */
#define CURLOPT_PROXYUSERPWD_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_PROXY_TRANSFER_MODE_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLOPT_PUT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_QUOTE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_RANDOM_FILE_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_RANGE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_READDATA_FIRST 0x070907 /* Added in 7.9.7 */
#define CURLOPT_READFUNCTION_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_REDIR_PROTOCOLS_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLOPT_REFERER_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_RESOLVE_FIRST 0x071503 /* Added in 7.21.3 */
#define CURLOPT_RESUME_FROM_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_RESUME_FROM_LARGE_FIRST 0x070b00 /* Added in 7.11.0 */
#define CURLOPT_RTSPHEADER_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_RTSP_CLIENT_CSEQ_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_RTSP_REQUEST_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_RTSP_SERVER_CSEQ_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_RTSP_SESSION_ID_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_RTSP_STREAM_URI_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_RTSP_TRANSPORT_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_SASL_IR_FIRST 0x071f00 /* Added in 7.31.0 */
#define CURLOPT_SEEKDATA_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLOPT_SEEKFUNCTION_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLOPT_SERVER_RESPONSE_TIMEOUT_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLOPT_SHARE_FIRST 0x070a00 /* Added in 7.10 */
#define CURLOPT_SOCKOPTDATA_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLOPT_SOCKOPTFUNCTION_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLOPT_SOCKS5_GSSAPI_NEC_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLOPT_SOCKS5_GSSAPI_SERVICE_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLOPT_SOURCE_HOST_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLOPT_SOURCE_HOST_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SOURCE_PATH_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLOPT_SOURCE_PATH_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SOURCE_PORT_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLOPT_SOURCE_PORT_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SOURCE_POSTQUOTE_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLOPT_SOURCE_POSTQUOTE_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SOURCE_PREQUOTE_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLOPT_SOURCE_PREQUOTE_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SOURCE_QUOTE_FIRST 0x070d00 /* Added in 7.13.0 */
#define CURLOPT_SOURCE_QUOTE_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SOURCE_URL_FIRST 0x070d00 /* Added in 7.13.0 */
#define CURLOPT_SOURCE_URL_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SOURCE_USERPWD_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURLOPT_SOURCE_USERPWD_LAST 0x070f05 /* Last featured in 7.15.5 */
#define CURLOPT_SSH_AUTH_TYPES_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLOPT_SSH_HOST_PUBLIC_KEY_MD5_FIRST 0x071101 /* Added in 7.17.1 */
#define CURLOPT_SSH_KEYDATA_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLOPT_SSH_KEYFUNCTION_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLOPT_SSH_KNOWNHOSTS_FIRST 0x071306 /* Added in 7.19.6 */
#define CURLOPT_SSH_PRIVATE_KEYFILE_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLOPT_SSH_PUBLIC_KEYFILE_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLOPT_SSLCERT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_SSLCERTPASSWD_FIRST 0x070101 /* Added in 7.1.1 */
#define CURLOPT_SSLCERTTYPE_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_SSLENGINE_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_SSLENGINE_DEFAULT_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_SSLKEY_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_SSLKEYPASSWD_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_SSLKEYTYPE_FIRST 0x070903 /* Added in 7.9.3 */
#define CURLOPT_SSLVERSION_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_SSL_CIPHER_LIST_FIRST 0x070900 /* Added in 7.9 */
#define CURLOPT_SSL_CTX_DATA_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLOPT_SSL_CTX_FUNCTION_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURLOPT_SSL_ENABLE_ALPN_FIRST 0x072400 /* Added in 7.36.0 */
#define CURLOPT_SSL_ENABLE_NPN_FIRST 0x072400 /* Added in 7.36.0 */
#define CURLOPT_SSL_OPTIONS_FIRST 0x071900 /* Added in 7.25.0 */
#define CURLOPT_SSL_SESSIONID_CACHE_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLOPT_SSL_VERIFYHOST_FIRST 0x070801 /* Added in 7.8.1 */
#define CURLOPT_SSL_VERIFYPEER_FIRST 0x070402 /* Added in 7.4.2 */
#define CURLOPT_SSL_VERIFYSTATUS_FIRST 0x072900 /* Added in 7.41.0 */
#define CURLOPT_STDERR_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_TCP_KEEPALIVE_FIRST 0x071900 /* Added in 7.25.0 */
#define CURLOPT_TCP_KEEPIDLE_FIRST 0x071900 /* Added in 7.25.0 */
#define CURLOPT_TCP_KEEPINTVL_FIRST 0x071900 /* Added in 7.25.0 */
#define CURLOPT_TCP_NODELAY_FIRST 0x070b02 /* Added in 7.11.2 */
#define CURLOPT_TELNETOPTIONS_FIRST 0x070700 /* Added in 7.7 */
#define CURLOPT_TFTP_BLKSIZE_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLOPT_TIMECONDITION_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_TIMEOUT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_TIMEOUT_MS_FIRST 0x071002 /* Added in 7.16.2 */
#define CURLOPT_TIMEVALUE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_TLSAUTH_PASSWORD_FIRST 0x071504 /* Added in 7.21.4 */
#define CURLOPT_TLSAUTH_TYPE_FIRST 0x071504 /* Added in 7.21.4 */
#define CURLOPT_TLSAUTH_USERNAME_FIRST 0x071504 /* Added in 7.21.4 */
#define CURLOPT_TRANSFERTEXT_FIRST 0x070101 /* Added in 7.1.1 */
#define CURLOPT_TRANSFER_ENCODING_FIRST 0x071506 /* Added in 7.21.6 */
#define CURLOPT_UNIX_SOCKET_PATH_FIRST 0x072800 /* Added in 7.40.0 */
#define CURLOPT_UNRESTRICTED_AUTH_FIRST 0x070a04 /* Added in 7.10.4 */
#define CURLOPT_UPLOAD_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_URL_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_USERAGENT_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_USERNAME_FIRST 0x071301 /* Added in 7.19.1 */
#define CURLOPT_USERPWD_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_USE_SSL_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLOPT_VERBOSE_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_WILDCARDMATCH_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLOPT_WRITEDATA_FIRST 0x070907 /* Added in 7.9.7 */
#define CURLOPT_WRITEFUNCTION_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_WRITEHEADER_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_WRITEINFO_FIRST 0x070100 /* Added in 7.1 */
#define CURLOPT_XFERINFODATA_FIRST 0x072000 /* Added in 7.32.0 */
#define CURLOPT_XFERINFOFUNCTION_FIRST 0x072000 /* Added in 7.32.0 */
#define CURLOPT_XOAUTH2_BEARER_FIRST 0x072100 /* Added in 7.33.0 */
#define CURLPAUSE_ALL_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLPAUSE_CONT_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLPAUSE_RECV_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLPAUSE_RECV_CONT_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLPAUSE_SEND_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLPAUSE_SEND_CONT_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLPROTO_ALL_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_DICT_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_FILE_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_FTP_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_FTPS_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_GOPHER_FIRST 0x071502 /* Added in 7.21.2 */
#define CURLPROTO_HTTP_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_HTTPS_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_IMAP_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLPROTO_IMAPS_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLPROTO_LDAP_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_LDAPS_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_POP3_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLPROTO_POP3S_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLPROTO_RTMP_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLPROTO_RTMPE_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLPROTO_RTMPS_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLPROTO_RTMPT_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLPROTO_RTMPTE_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLPROTO_RTMPTS_FIRST 0x071500 /* Added in 7.21.0 */
#define CURLPROTO_RTSP_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLPROTO_SCP_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_SFTP_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_SMB_FIRST 0x072800 /* Added in 7.40.0 */
#define CURLPROTO_SMBS_FIRST 0x072800 /* Added in 7.40.0 */
#define CURLPROTO_SMTP_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLPROTO_SMTPS_FIRST 0x071400 /* Added in 7.20.0 */
#define CURLPROTO_TELNET_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROTO_TFTP_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROXY_HTTP_FIRST 0x070a00 /* Added in 7.10 */
#define CURLPROXY_HTTP_1_0_FIRST 0x071304 /* Added in 7.19.4 */
#define CURLPROXY_SOCKS4_FIRST 0x070a00 /* Added in 7.10 */
#define CURLPROXY_SOCKS4A_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLPROXY_SOCKS5_FIRST 0x070a00 /* Added in 7.10 */
#define CURLPROXY_SOCKS5_HOSTNAME_FIRST 0x071200 /* Added in 7.18.0 */
#define CURLSHE_BAD_OPTION_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHE_INVALID_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHE_IN_USE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHE_NOMEM_FIRST 0x070c00 /* Added in 7.12.0 */
#define CURLSHE_NOT_BUILT_IN_FIRST 0x071700 /* Added in 7.23.0 */
#define CURLSHE_OK_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHOPT_LOCKFUNC_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHOPT_NONE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHOPT_SHARE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHOPT_UNLOCKFUNC_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHOPT_UNSHARE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSHOPT_USERDATA_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURLSOCKTYPE_ACCEPT_FIRST 0x071c00 /* Added in 7.28.0 */
#define CURLSOCKTYPE_IPCXN_FIRST 0x071000 /* Added in 7.16.0 */
#define CURLSSH_AUTH_AGENT_FIRST 0x071c00 /* Added in 7.28.0 */
#define CURLSSH_AUTH_ANY_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLSSH_AUTH_DEFAULT_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLSSH_AUTH_HOST_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLSSH_AUTH_KEYBOARD_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLSSH_AUTH_NONE_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLSSH_AUTH_PASSWORD_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLSSH_AUTH_PUBLICKEY_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLSSLBACKEND_AXTLS_FIRST 0x072600 /* Added in 7.38.0 */
#define CURLSSLBACKEND_CYASSL_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_DARWINSSL_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_GNUTLS_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_GSKIT_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_NONE_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_NSS_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_OPENSSL_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_POLARSSL_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_QSOSSL_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLBACKEND_QSOSSL_LAST 0x072601 /* Last featured in 7.38.1 */
#define CURLSSLBACKEND_SCHANNEL_FIRST 0x072200 /* Added in 7.34.0 */
#define CURLSSLOPT_ALLOW_BEAST_FIRST 0x071900 /* Added in 7.25.0 */
#define CURLUSESSL_ALL_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLUSESSL_CONTROL_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLUSESSL_NONE_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLUSESSL_TRY_FIRST 0x071100 /* Added in 7.17.0 */
#define CURLVERSION_FIRST_FIRST 0x070a00 /* Added in 7.10 */
#define CURLVERSION_FOURTH_FIRST 0x071001 /* Added in 7.16.1 */
#define CURLVERSION_NOW_FIRST 0x070a00 /* Added in 7.10 */
#define CURLVERSION_SECOND_FIRST 0x070b01 /* Added in 7.11.1 */
#define CURLVERSION_THIRD_FIRST 0x070c00 /* Added in 7.12.0 */
#define CURL_CHUNK_BGN_FUNC_FAIL_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_CHUNK_BGN_FUNC_OK_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_CHUNK_BGN_FUNC_SKIP_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_CHUNK_END_FUNC_FAIL_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_CHUNK_END_FUNC_OK_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_CSELECT_ERR_FIRST 0x071003 /* Added in 7.16.3 */
#define CURL_CSELECT_IN_FIRST 0x071003 /* Added in 7.16.3 */
#define CURL_CSELECT_OUT_FIRST 0x071003 /* Added in 7.16.3 */
#define CURL_EASY_NONE_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_EASY_NONE_LAST 0x070f04 /* Last featured in 7.15.4 */
#define CURL_EASY_TIMEOUT_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_EASY_TIMEOUT_LAST 0x070f04 /* Last featured in 7.15.4 */
#define CURL_ERROR_SIZE_FIRST 0x070100 /* Added in 7.1 */
#define CURL_FNMATCHFUNC_FAIL_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_FNMATCHFUNC_MATCH_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_FNMATCHFUNC_NOMATCH_FIRST 0x071500 /* Added in 7.21.0 */
#define CURL_FORMADD_DISABLED_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURL_FORMADD_ILLEGAL_ARRAY_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_FORMADD_INCOMPLETE_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_FORMADD_MEMORY_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_FORMADD_NULL_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_FORMADD_OK_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_FORMADD_OPTION_TWICE_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_FORMADD_UNKNOWN_OPTION_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_GLOBAL_ACK_EINTR_FIRST 0x071e00 /* Added in 7.30.0 */
#define CURL_GLOBAL_ALL_FIRST 0x070800 /* Added in 7.8 */
#define CURL_GLOBAL_DEFAULT_FIRST 0x070800 /* Added in 7.8 */
#define CURL_GLOBAL_NOTHING_FIRST 0x070800 /* Added in 7.8 */
#define CURL_GLOBAL_SSL_FIRST 0x070800 /* Added in 7.8 */
#define CURL_GLOBAL_WIN32_FIRST 0x070801 /* Added in 7.8.1 */
#define CURL_HTTP_VERSION_1_0_FIRST 0x070901 /* Added in 7.9.1 */
#define CURL_HTTP_VERSION_1_1_FIRST 0x070901 /* Added in 7.9.1 */
#define CURL_HTTP_VERSION_2_0_FIRST 0x072100 /* Added in 7.33.0 */
#define CURL_HTTP_VERSION_NONE_FIRST 0x070901 /* Added in 7.9.1 */
#define CURL_IPRESOLVE_V4_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURL_IPRESOLVE_V6_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURL_IPRESOLVE_WHATEVER_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURL_LOCK_ACCESS_NONE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_ACCESS_SHARED_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_ACCESS_SINGLE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_DATA_CONNECT_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_DATA_COOKIE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_DATA_DNS_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_DATA_NONE_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_DATA_SHARE_FIRST 0x070a04 /* Added in 7.10.4 */
#define CURL_LOCK_DATA_SSL_SESSION_FIRST 0x070a03 /* Added in 7.10.3 */
#define CURL_LOCK_TYPE_CONNECT_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_LOCK_TYPE_CONNECT_LAST 0x070a02 /* Last featured in 7.10.2 */
#define CURL_LOCK_TYPE_COOKIE_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_LOCK_TYPE_COOKIE_LAST 0x070a02 /* Last featured in 7.10.2 */
#define CURL_LOCK_TYPE_DNS_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_LOCK_TYPE_DNS_LAST 0x070a02 /* Last featured in 7.10.2 */
#define CURL_LOCK_TYPE_NONE_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_LOCK_TYPE_NONE_LAST 0x070a02 /* Last featured in 7.10.2 */
#define CURL_LOCK_TYPE_SSL_SESSION_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_LOCK_TYPE_SSL_SESSION_LAST 0x070a02 /* Last featured in 7.10.2 */
#define CURL_MAX_HTTP_HEADER_FIRST 0x071307 /* Added in 7.19.7 */
#define CURL_MAX_WRITE_SIZE_FIRST 0x070907 /* Added in 7.9.7 */
#define CURL_NETRC_IGNORED_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_NETRC_OPTIONAL_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_NETRC_REQUIRED_FIRST 0x070908 /* Added in 7.9.8 */
#define CURL_POLL_IN_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_POLL_INOUT_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_POLL_NONE_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_POLL_OUT_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_POLL_REMOVE_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_PROGRESS_BAR_FIRST 0x070101 /* Added in 7.1.1 */
#define CURL_PROGRESS_BAR_LAST 0x070401 /* Last featured in 7.4.1 */
#define CURL_PROGRESS_STATS_FIRST 0x070101 /* Added in 7.1.1 */
#define CURL_PROGRESS_STATS_LAST 0x070401 /* Last featured in 7.4.1 */
#define CURL_READFUNC_ABORT_FIRST 0x070c01 /* Added in 7.12.1 */
#define CURL_READFUNC_PAUSE_FIRST 0x071200 /* Added in 7.18.0 */
#define CURL_REDIR_GET_ALL_FIRST 0x071301 /* Added in 7.19.1 */
#define CURL_REDIR_POST_301_FIRST 0x071301 /* Added in 7.19.1 */
#define CURL_REDIR_POST_302_FIRST 0x071301 /* Added in 7.19.1 */
#define CURL_REDIR_POST_303_FIRST 0x071901 /* Added in 7.25.1 */
#define CURL_REDIR_POST_ALL_FIRST 0x071301 /* Added in 7.19.1 */
#define CURL_RTSPREQ_ANNOUNCE_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_DESCRIBE_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_GET_PARAMETER_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_NONE_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_OPTIONS_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_PAUSE_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_PLAY_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_RECEIVE_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_RECORD_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_SETUP_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_SET_PARAMETER_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_RTSPREQ_TEARDOWN_FIRST 0x071400 /* Added in 7.20.0 */
#define CURL_SEEKFUNC_CANTSEEK_FIRST 0x071305 /* Added in 7.19.5 */
#define CURL_SEEKFUNC_FAIL_FIRST 0x071305 /* Added in 7.19.5 */
#define CURL_SEEKFUNC_OK_FIRST 0x071305 /* Added in 7.19.5 */
#define CURL_SOCKET_BAD_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_SOCKET_TIMEOUT_FIRST 0x070e00 /* Added in 7.14.0 */
#define CURL_SOCKOPT_ALREADY_CONNECTED_FIRST 0x071505 /* Added in 7.21.5 */
#define CURL_SOCKOPT_ERROR_FIRST 0x071505 /* Added in 7.21.5 */
#define CURL_SOCKOPT_OK_FIRST 0x071505 /* Added in 7.21.5 */
#define CURL_SSLVERSION_DEFAULT_FIRST 0x070902 /* Added in 7.9.2 */
#define CURL_SSLVERSION_SSLv2_FIRST 0x070902 /* Added in 7.9.2 */
#define CURL_SSLVERSION_SSLv3_FIRST 0x070902 /* Added in 7.9.2 */
#define CURL_SSLVERSION_TLSv1_FIRST 0x070902 /* Added in 7.9.2 */
#define CURL_SSLVERSION_TLSv1_0_FIRST 0x072200 /* Added in 7.34.0 */
#define CURL_SSLVERSION_TLSv1_1_FIRST 0x072200 /* Added in 7.34.0 */
#define CURL_SSLVERSION_TLSv1_2_FIRST 0x072200 /* Added in 7.34.0 */
#define CURL_TIMECOND_IFMODSINCE_FIRST 0x070907 /* Added in 7.9.7 */
#define CURL_TIMECOND_IFUNMODSINCE_FIRST 0x070907 /* Added in 7.9.7 */
#define CURL_TIMECOND_LASTMOD_FIRST 0x070907 /* Added in 7.9.7 */
#define CURL_TIMECOND_NONE_FIRST 0x070907 /* Added in 7.9.7 */
#define CURL_TLSAUTH_NONE_FIRST 0x071504 /* Added in 7.21.4 */
#define CURL_TLSAUTH_SRP_FIRST 0x071504 /* Added in 7.21.4 */
#define CURL_VERSION_ASYNCHDNS_FIRST 0x070a07 /* Added in 7.10.7 */
#define CURL_VERSION_CONV_FIRST 0x070f04 /* Added in 7.15.4 */
#define CURL_VERSION_CURLDEBUG_FIRST 0x071306 /* Added in 7.19.6 */
#define CURL_VERSION_DEBUG_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURL_VERSION_GSSAPI_FIRST 0x072600 /* Added in 7.38.0 */
#define CURL_VERSION_GSSNEGOTIATE_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURL_VERSION_HTTP2_FIRST 0x072100 /* Added in 7.33.0 */
#define CURL_VERSION_IDN_FIRST 0x070c00 /* Added in 7.12.0 */
#define CURL_VERSION_IPV6_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_VERSION_KERBEROS4_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_VERSION_KERBEROS5_FIRST 0x072800 /* Added in 7.40.0 */
#define CURL_VERSION_LARGEFILE_FIRST 0x070b01 /* Added in 7.11.1 */
#define CURL_VERSION_LIBZ_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_VERSION_NTLM_FIRST 0x070a06 /* Added in 7.10.6 */
#define CURL_VERSION_NTLM_WB_FIRST 0x071600 /* Added in 7.22.0 */
#define CURL_VERSION_SPNEGO_FIRST 0x070a08 /* Added in 7.10.8 */
#define CURL_VERSION_SSL_FIRST 0x070a00 /* Added in 7.10 */
#define CURL_VERSION_SSPI_FIRST 0x070d02 /* Added in 7.13.2 */
#define CURL_VERSION_TLSAUTH_SRP_FIRST 0x071504 /* Added in 7.21.4 */
#define CURL_VERSION_UNIX_SOCKETS_FIRST 0x072800 /* Added in 7.40.0 */
#define CURL_WAIT_POLLIN_FIRST 0x071c00 /* Added in 7.28.0 */
#define CURL_WAIT_POLLOUT_FIRST 0x071c00 /* Added in 7.28.0 */
#define CURL_WAIT_POLLPRI_FIRST 0x071c00 /* Added in 7.28.0 */
#define CURL_WRITEFUNC_PAUSE_FIRST 0x071200 /* Added in 7.18.0 */
